package com.zehong.monitorreprotdatafrogovernmentnew.config;

import com.alibaba.druid.pool.DruidDataSource;
import org.apache.ibatis.session.SqlSessionFactory;
import org.mybatis.spring.SqlSessionFactoryBean;
import org.mybatis.spring.annotation.MapperScan;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Primary;
import org.springframework.core.io.support.PathMatchingResourcePatternResolver;
import org.springframework.jdbc.datasource.DataSourceTransactionManager;

import javax.sql.DataSource;

@Configuration
@MapperScan(basePackages = JingyeDataSourceConfig.PACKAGE, sqlSessionFactoryRef = "jingyeSqlSessionFactory")
public class JingyeDataSourceConfig {

    // 精确到 jingye 目录，以便跟其他数据源隔离
    static final String PACKAGE = "com.zehong.monitorreprotdatafrogovernmentnew.dao.jingye";
    static final String MAPPER_LOCATION = "classpath:mapper/jingye/*.xml";

    @Value("${jingye.datasource.url}")
    private String url;

    @Value("${jingye.datasource.username}")
    private String user;

    @Value("${jingye.datasource.password}")
    private String password;

    @Value("${jingye.datasource.driverClassName}")
    private String driverClass;

    @Bean(name = "jingyeDataSource")
    @Primary
    public DataSource jingyeDataSource() {
        DruidDataSource dataSource = new DruidDataSource();
        dataSource.setDriverClassName(driverClass);
        dataSource.setUrl(url);
        dataSource.setUsername(user);
        dataSource.setPassword(password);
        return dataSource;
    }

    @Bean(name = "jingyeTransactionManager")
    @Primary
    public DataSourceTransactionManager jingyeTransactionManager() {
        return new DataSourceTransactionManager(jingyeDataSource());
    }

    @Bean(name = "jingyeSqlSessionFactory")
    @Primary
    public SqlSessionFactory jingyeSqlSessionFactory(@Qualifier("jingyeDataSource") DataSource jingyeDataSource)
            throws Exception {
        final SqlSessionFactoryBean sessionFactory = new SqlSessionFactoryBean();
        sessionFactory.setDataSource(jingyeDataSource);
        sessionFactory.setMapperLocations(new PathMatchingResourcePatternResolver()
                .getResources(JingyeDataSourceConfig.MAPPER_LOCATION));
        return sessionFactory.getObject();
    }
}
