package com.zehong.monitorreprotdatafrogovernmentnew.config;

import com.alibaba.druid.pool.DruidDataSource;
import org.apache.ibatis.session.SqlSessionFactory;
import org.mybatis.spring.SqlSessionFactoryBean;
import org.mybatis.spring.annotation.MapperScan;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.core.io.support.PathMatchingResourcePatternResolver;
import org.springframework.jdbc.datasource.DataSourceTransactionManager;

import javax.sql.DataSource;

@Configuration
@MapperScan(basePackages = YingdeDataSourceConfig.PACKAGE, sqlSessionFactoryRef = "yingdeSqlSessionFactory")
public class YingdeDataSourceConfig {

    // 精确到 yingde 目录，以便跟其他数据源隔离
    static final String PACKAGE = "com.zehong.monitorreprotdatafrogovernmentnew.dao.yingde";
    static final String MAPPER_LOCATION = "classpath:mapper/yingde/*.xml";

    @Value("${yingde.datasource.url}")
    private String url;

    @Value("${yingde.datasource.username}")
    private String user;

    @Value("${yingde.datasource.password}")
    private String password;

    @Value("${yingde.datasource.driverClassName}")
    private String driverClass;

    @Bean(name = "yingdeDataSource")
    public DataSource yingdeDataSource() {
        DruidDataSource dataSource = new DruidDataSource();
        dataSource.setDriverClassName(driverClass);
        dataSource.setUrl(url);
        dataSource.setUsername(user);
        dataSource.setPassword(password);
        return dataSource;
    }

    @Bean(name = "yingdeTransactionManager")
    public DataSourceTransactionManager yingdeTransactionManager() {
        return new DataSourceTransactionManager(yingdeDataSource());
    }

    @Bean(name = "yingdeSqlSessionFactory")
    public SqlSessionFactory yingdeSqlSessionFactory(@Qualifier("yingdeDataSource") DataSource yingdeDataSource)
            throws Exception {
        final SqlSessionFactoryBean sessionFactory = new SqlSessionFactoryBean();
        sessionFactory.setDataSource(yingdeDataSource);
        sessionFactory.setMapperLocations(new PathMatchingResourcePatternResolver()
                .getResources(YingdeDataSourceConfig.MAPPER_LOCATION));
        return sessionFactory.getObject();
    }
}
