package com.zehong.monitorreprotdatafrogovernmentnew.config;

import com.alibaba.druid.pool.DruidDataSource;
import org.apache.ibatis.session.SqlSessionFactory;
import org.mybatis.spring.SqlSessionFactoryBean;
import org.mybatis.spring.annotation.MapperScan;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.core.io.support.PathMatchingResourcePatternResolver;
import org.springframework.jdbc.datasource.DataSourceTransactionManager;

import javax.sql.DataSource;

@Configuration
@MapperScan(basePackages = ZhengyuanDataSourceConfig.PACKAGE, sqlSessionFactoryRef = "zhengyuanSqlSessionFactory")
public class ZhengyuanDataSourceConfig {

    // 精确到 zhengyuan 目录，以便跟其他数据源隔离
    static final String PACKAGE = "com.zehong.monitorreprotdatafrogovernmentnew.dao.zhengyuan";
    static final String MAPPER_LOCATION = "classpath:mapper/zhengyuan/*.xml";

    @Value("${zhengyuan.datasource.url}")
    private String url;

    @Value("${zhengyuan.datasource.username}")
    private String user;

    @Value("${zhengyuan.datasource.password}")
    private String password;

    @Value("${zhengyuan.datasource.driverClassName}")
    private String driverClass;

    @Bean(name = "zhengyuanDataSource")
    public DataSource zhengyuanDataSource() {
        DruidDataSource dataSource = new DruidDataSource();
        dataSource.setDriverClassName(driverClass);
        dataSource.setUrl(url);
        dataSource.setUsername(user);
        dataSource.setPassword(password);
        return dataSource;
    }

    @Bean(name = "zhengyuanTransactionManager")
    public DataSourceTransactionManager zhengyuanTransactionManager() {
        return new DataSourceTransactionManager(zhengyuanDataSource());
    }

    @Bean(name = "zhengyuanSqlSessionFactory")
    public SqlSessionFactory zhengyuanSqlSessionFactory(@Qualifier("zhengyuanDataSource") DataSource zhengyuanDataSource)
            throws Exception {
        final SqlSessionFactoryBean sessionFactory = new SqlSessionFactoryBean();
        sessionFactory.setDataSource(zhengyuanDataSource);
        sessionFactory.setMapperLocations(new PathMatchingResourcePatternResolver()
                .getResources(ZhengyuanDataSourceConfig.MAPPER_LOCATION));
        return sessionFactory.getObject();
    }
}
