package com.zehong.monitorreprotdatafrogovernmentnew.task;

import com.alibaba.fastjson.JSONObject;
import com.zehong.monitorreprotdatafrogovernmentnew.model.SendSmsParam;
import com.zehong.monitorreprotdatafrogovernmentnew.result.Result;
import com.zehong.monitorreprotdatafrogovernmentnew.result.ResultEnum;
import com.zehong.monitorreprotdatafrogovernmentnew.utils.HttpUtil;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.scheduling.concurrent.ThreadPoolTaskScheduler;
import org.springframework.scheduling.support.CronTrigger;
import org.springframework.stereotype.Component;

import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.ScheduledFuture;

@Component
public class SendSmsTask {

    private static final Logger logger = LoggerFactory.getLogger(SendSmsTask.class);
    private Map<String, ScheduledFuture<?>> taskMap = new HashMap<>();
    @Value("${secretKey}")
    private String secretKey;
    @Value("${phoneNums}")
    private String[] phoneNums;
    @Value("${signName}")
    private String signName;
    @Value("${templateCode}")
    private String templateCode;
    @Value("${sendSmsUrl}")
    private String sendSmsUrl;

    @Autowired
    private ThreadPoolTaskScheduler threadPoolTaskScheduler;

    public boolean add(String name, String cron) {
         if(null != taskMap.get(name)) {
             return false;
         }
         ScheduledFuture<?> schedule = threadPoolTaskScheduler.schedule(new TaskRunnable(name), new CronTrigger(cron));
         taskMap.put(name, schedule);
         return true;
     }

    public boolean stop(String name) {
         if(null == taskMap.get(name)) {
             return false;
         }
         ScheduledFuture<?> scheduledFuture = taskMap.get(name);
         scheduledFuture.cancel(true);
         taskMap.remove(name);
         return true;
     }

     public boolean isExist(String task){
        return taskMap.containsKey(task);
     }


    private class TaskRunnable implements Runnable {
        private String name;
        public TaskRunnable(String name) {
            this.name = name;
        }
        @Override
        public void run() {
            sendSms(name);
        }

    }

    public void sendSms(String company){
        String param = JSONObject.toJSONString(assemableParam(company));
        try {
            logger.info("发送短信参数为："+param);
            Result result = HttpUtil.doPost(sendSmsUrl,param);
            if(ResultEnum.FAIL.getCode().equals(result.getCode()) || !"0".equals(JSONObject.parseObject(result.getMsg()).get("code"))){
                throw new Exception(result.getMsg());
            }
        } catch (Exception e) {
            logger.error("发送短信失败："+e);
            logger.error("发送短信失败参数为："+param);
        }
    }

    /**
     * 获取公司名称
     * @param company 公司标志
     * @return String
     */
    private String getCompanyName(String company){
        switch(company){
            case "jingye":
                company = "敬业";
                break;
            case "yingde":
                company = "盈得";
                break;
            case "zhengyuan":
                company = "正元";
                break;
            default:
                company = "";
        }
        return company;
    }

    /**
     * 拼装请求参数
     * @param company 公司
     * @return SendSmsParam
     */
    private SendSmsParam assemableParam(String company){
        SendSmsParam sendSmsParam = new SendSmsParam();
        sendSmsParam.setSecretKey(secretKey);
        StringBuilder phoneNumberJson = new StringBuilder("[");
        StringBuilder signNameJson = new StringBuilder("[");
        StringBuilder templateParamJson = new StringBuilder("[");
        for(String phone : phoneNums){
            phoneNumberJson.append("\"");
            phoneNumberJson.append(phone);
            phoneNumberJson.append("\",");
            signNameJson.append("\"");
            signNameJson.append(signName);
            signNameJson.append("\",");
            templateParamJson.append("{\"company\":\"");
            templateParamJson.append(getCompanyName(company));
            templateParamJson.append("\"},");
        }
        //群发号码
        phoneNumberJson.deleteCharAt(phoneNumberJson.length() - 1);
        phoneNumberJson.append("]");
        //群发签名
        signNameJson.deleteCharAt(signNameJson.length() - 1);
        signNameJson.append("]");
        //群发内容
        templateParamJson.deleteCharAt(templateParamJson.length() - 1);
        templateParamJson.append("]");
        sendSmsParam.setPhoneNumberJson(phoneNumberJson.toString());
        sendSmsParam.setSignNameJson(signNameJson.toString());
        sendSmsParam.setTemplateCode(templateCode);
        sendSmsParam.setTemplateParamJson(templateParamJson.toString());
        return sendSmsParam;
    }


}
